@@ -1,12 +1,22 @@
 import json, sys
 import traceback
 import logging
-from PyQt5 import QtWidgets, QtCore
-from PyQt5.QtGui import *
-from PyQt5.QtCore import *
-from PyQt5.QtWebChannel import QWebChannel
-from PyQt5.QtWidgets import *
-from PyQt5.QtWebEngineWidgets import *
+
+try:
+    from PyQt6 import QtWidgets, QtCore
+    from PyQt6.QtGui import *
+    from PyQt6.QtCore import *
+    from PyQt6.QtWebChannel import QWebChannel
+    from PyQt6.QtWidgets import *
+    from PyQt6.QtWebEngineWidgets import *
+except:
+    from PyQt5 import QtWidgets, QtCore
+    from PyQt5.QtGui import *
+    from PyQt5.QtCore import *
+    from PyQt5.QtWebChannel import QWebChannel
+    from PyQt5.QtWidgets import *
+    from PyQt5.QtWebEngineWidgets import *
+
 from pyhtmlgui import Observable
 QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_EnableHighDpiScaling, True)  # enable highdpi scaling
 QtWidgets.QApplication.setAttribute(QtCore.Qt.AA_UseHighDpiPixmaps, True)  # use highdpi icons
